@@ -20,6 +20,7 @@ class BundleVolParameters < BundleMachineParameters
   INCLUDE_DESCRIPTION       = ["Linux Only. A comma-separated list of absolute file paths, relative to the volume",
                                "being bundled, to include. This option overrides the default filtered",
                                "files list."]
+  FILTER_DESCRIPTION        = "Do not use the default filtered files list."
   ALL_DESCRIPTION           = ["Include all directories in the volume being bundled, including those",
                                "on remotely mounted filesystems."]
   SIZE_DESCRIPTION          = ["The size, in MB (1024 * 1024 bytes), of the image file to create.",
@@ -35,6 +36,7 @@ class BundleVolParameters < BundleMachineParameters
   attr_accessor :all,
                 :exclude,
                 :includes,
+                :filter,
                 :prefix,
                 :size,
                 :volume,
@@ -55,6 +57,10 @@ class BundleVolParameters < BundleMachineParameters
     on('-i', '--include FILE1,FILE2,...', Array, *INCLUDE_DESCRIPTION) do |p|
       @includes = p
     end
+
+    on('--no-filter', FILTER_DESCRIPTION) do
+      @filter = false
+    end
     
     on('-p', '--prefix PREFIX', String, PREFIX_DESCRIPTION) do |prefix|
       assert_good_key(prefix, '--prefix')
@@ -111,6 +117,7 @@ class BundleVolParameters < BundleMachineParameters
     @inherit = true if @inherit.nil? # false means a parameter was provided.
     @exclude ||= []
     @includes ||= []
+    @filter = true if @filter.nil?
     @prefix ||= 'image'
     @size ||= MAX_SIZE_MB
     @volume ||= '/'
