@@ -9,6 +9,7 @@
 # limitations under the License.
 
 require 'ec2/common/s3support'
+require 'ec2/amitools/region'
 require 'ec2/amitools/migratebundleparameters'
 require 'ec2/amitools/migratemanifest'
 require 'ec2/amitools/downloadbundle'
@@ -149,12 +150,7 @@ class BundleMigrator < AMITool
     # Region/location hack:
     if region.nil?
       location ||= bucket_location
-      region = "us-east-1"
-      region = "eu-west-1"      if location == "EU"
-      region = "us-west-1"      if location == "us-west-1"
-      region = "ap-southeast-1" if location == "ap-southeast-1"
-      region = "ap-northeast-1" if location == "ap-northeast-1"
-      region = "us-west-2"      if location == "us-west-2"
+      region = AwsRegion.guess_region_from_s3_bucket(location)
       puts "Region not provided, guessing from S3 location: #{region}"
     end
     
