@@ -44,6 +44,7 @@ module EC2
                         mb_image_size,
                         exclude,
                         includes,
+                        filter = true,
                         fstab = nil,
                         debug = false )
           @volume = volume
@@ -51,6 +52,7 @@ module EC2
           @mb_image_size = mb_image_size
           @exclude = exclude
           @includes = includes
+          @filter = filter
           @fstab = nil
           # Cunning plan or horrible hack?
           # If :legacy is passed in as the fstab, we use the old v3 manifest's
@@ -141,17 +143,17 @@ module EC2
           mkfs = [ '/sbin/mkfs.' + type ]
           case type
           when 'btrfs'
-            mkfs << [ '-L', label] if label
+            mkfs << [ '-L', label] if !label.to_s.empty?
             mkfs << [ @image_filename ]
           when 'xfs'
-            mkfs << [ '-L', label] if label
+            mkfs << [ '-L', label] if !label.to_s.empty?
             mkfs << [ @image_filename ]
             tune =  [ '/usr/sbin/xfs_admin' ]
             tune << [ '-U', uuid ] if uuid
             tune << [ @image_filename ]
           else
             # type unknown or ext2 or ext3 or ext4
-            mkfs << [ '-L', label] if label
+            mkfs << [ '-L', label] if !label.to_s.empty?
             mkfs << [ '-F', @image_filename ]   
             tune =  [ '/sbin/tune2fs -i 0' ]
             tune << [ '-U', uuid ] if uuid
@@ -201,7 +203,10 @@ module EC2
         def copy_rec( src, dst, options={:xattributes => true} )
           begin
             rsync = EC2::Platform::Linux::Rsync::Command.new
-            rsync.archive.times.recursive.sparse.links.quietly.include(@includes).exclude(@exclude).exclude(EC2::Platform::Linux::Constants::Security::FILE_FILTER)
+            rsync.archive.times.recursive.sparse.links.quietly.include(@includes).exclude(@exclude)
+            if @filter
+              rsync.exclude(EC2::Platform::Linux::Constants::Security::FILE_FILTER)
+            end
             rsync.xattributes if options[ :xattributes ]
             rsync.src(File::join( src, '*' )).dst(dst)
             execute(rsync.expand)
